@@ -6,8 +6,8 @@ from enum import IntEnum, auto as _enum_auto
 # noinspection PyArgumentList
 class ExitCode(IntEnum):
     # No errors occurred
-    SUCCESS: ExitCode = 0
+    SUCCESS: ExitCode = 0  # type: ignore
     # Steamworks API related error
-    STEAMWORKS_ERROR: ExitCode = _enum_auto()
+    STEAMWORKS_ERROR: ExitCode = _enum_auto()  # type: ignore
     # Unsupported platform
-    UNSUPPORTED_PLATFORM: ExitCode = _enum_auto()
+    UNSUPPORTED_PLATFORM: ExitCode = _enum_auto()  # type: ignore
